local Addon = LibStub("AceAddon-3.0"):GetAddon("iGuild");
local L = LibStub("AceLocale-3.0"):GetLocale("iGuild");

local function CreateConfig()
	local db = {
		type = "group",
		name = "iGuild",
		order = 1,
		get = function(info)
			return Addon.db.Column[info.arg.k][info.arg.v];
		end,
		set = function(info, value)
			Addon.db.Column[info.arg.k][info.arg.v] = value;
		end,
		args = {},
	};
	
	local i = 1
	for k, v in pairs(Addon.Columns) do
		db.args["Header"..i] = {
			type = "header",
			name = L["Column"]..": "..v.Label,
			order = i
		};
		i = i + 1;
		
		db.args["ShowLabel"..i] = {
			type = "toggle",
			name = L["Show Label"],
			order = i,
			arg = {
				k = k,
				v = "ShowLabel",
			},
		};
		i = i + 1;
		
		db.args["Align"..i] = {
			type = "select",
			name = L["Align"],
			order = i,
			values = {
				["LEFT"] = L["Left"],
				["CENTER"] = L["Center"],
				["RIGHT"] = L["Right"],
			},
			arg = {
				k = k,
				v = "Align",
			},
		};
		i = i + 1;
	end
	
	return db;
end

local function CreateDB()
	local opt = { "ShowLabel", "Align" };
	local db = {
		Display = { "level", "name", "zone", "rank", "note" },
		Column = {},
	};

	for k, v in pairs(Addon.Columns) do
		if( not db.Column[k] ) then
			db.Column[k] = {};
		end
		
		for i = 1, #opt do
			db.Column[k][opt[i]] = Addon.Columns[k][opt[i]];
			Addon.Columns[k][opt[i]] = nil;
		end
		
	end
	
	db = { profile = db };
	return db;
end

function Addon:OpenOptions()
	LibStub("AceConfigDialog-3.0"):Open("iGuild");
end

Addon.db = LibStub("AceDB-3.0"):New("iGuildDB", CreateDB(), "Default").profile;
LibStub("AceConfig-3.0"):RegisterOptionsTable("iGuild", CreateConfig);
LibStub("AceConfigDialog-3.0"):AddToBlizOptions("iGuild")
_G.SlashCmdList["IGUILD"] = Addon.OpenOptions;
_G["SLASH_IGUILD1"] = "/iguild";